Learn R Programming

stats19 (version 4.1.0)

get_url: Convert file names to urls

Description

Convert file names to urls

Usage

get_url(
  file_name = "",
  domain = "https://data.dft.gov.uk",
  directory = "road-accidents-safety-data"
)

Arguments

file_name

Optional file name to add to the url returned (empty by default)

domain

The domain from where the data will be downloaded

directory

The subdirectory of the url

Examples

Run this code
# get_url(find_file_name(1985))

Run the code above in your browser using DataLab