Read in STATS19 road safety data from .csv files downloaded.
read_casualties(
year = NULL,
filename = "",
data_dir = get_data_directory(),
format = TRUE
)Single year, or vector of years, for which data are to be
read. Use "all" (or any year before 2021) to read the full 1979-latest
dataset in one file; see find_file_name() for details.
Character string of the filename of the .csv to read, if this is given, type and years determine whether there is a target to read, otherwise disk scan would be needed.
Where sets of downloaded data would be found.
Switch to return raw read from file, default is TRUE.