read_collisions: Read in STATS19 road safety data from .csv files downloaded.
Description
Read in STATS19 road safety data from .csv files downloaded.
Usage
read_collisions(
year = NULL,
filename = "",
data_dir = get_data_directory(),
format = TRUE,
silent = FALSE
)
Arguments
year
Single year, or vector of years, for which data are to be
read. Use "all" (or any year before 2021) to read the full 1979-latest
dataset in one file; see find_file_name() for details.
filename
Character string of the filename of the .csv to read, if this is given, type and
years determine whether there is a target to read, otherwise disk scan would be needed.
data_dir
Where sets of downloaded data would be found.
format
Switch to return raw read from file, default is TRUE.
silent
Boolean. If FALSE (default value), display useful progress
messages on the screen.
Details
This is a wrapper function to access and load stats 19 data in a user-friendly way.
The function returns a data frame, in which each record is a reported incident in the
STATS19 data.