| dl_stats19 | R Documentation |
Download STATS19 data for a year
dl_stats19(
year = NULL,
type = NULL,
data_dir = get_data_directory(),
file_name = NULL,
ask = FALSE,
silent = FALSE,
timeout = 600
)
year |
Single year for which data are to be read |
type |
One of 'collision', 'casualty', 'Vehicle'; defaults to 'collision'. |
data_dir |
Where sets of downloaded data would be found. |
file_name |
Character string of a specific STATS19 CSV filename to
download/read. If |
ask |
Should you be asked whether or not to download the files? |
silent |
Boolean. If |
timeout |
Timeout in seconds for the download if current option is less than this value. Defaults to 600 (10 minutes). |
if (curl::has_internet()) {
# type by default is collisions table
dl_stats19(year = 2022)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.