powered by
Convert file names to urls
get_url( file_name = "", domain = "https://data.dft.gov.uk", directory = "road-accidents-safety-data" )
Optional file name to add to the url returned (empty by default)
The domain from where the data will be downloaded
The subdirectory of the url
# get_url(find_file_name(1985))
Run the code above in your browser using DataLab